@@ -10,10 +10,14 @@ import uuid
 from datetime import datetime
 from typing import Any, Dict, Iterable, List, Optional, Type
 
-import attrs
-
 from .exceptions import UnknownDeviceType
 
+try:
+    import attrs
+except ModuleNotFoundError:
+    # Handle attrs<21.3.0
+    import attr as attrs  # type: ignore[no-redef]
+
 
 def _date_converter(val: Optional[str]) -> Optional[datetime]:
     """Converts a datetime in RFC3339 format to datetime object."""
@@ -223,6 +227,13 @@ class TrackerConfig:
     )
     """Image reference when icon as been replaced by a user-defined image."""
 
+    weight: Optional[float] = attrs.field(
+        converter=attrs.converters.optional(float),
+        validator=attrs.validators.optional(attrs.validators.instance_of(float)),
+        default=None,
+    )
+    """To be determined. Probably weight of object to which tracker is attached."""
+
 
 @attrs.define(auto_attribs=True)
 class TrackerStatus:
